<?php
/**
 * Manage categories backend and frontend
 *
 * @link       https://odude.com/
 * @since      1.0.0
 * @author     ODude <navneet@odude.com>
 * @package    Flexi
 * @subpackage Flexi/includes
 */
class Flexi_Category
{

    public function __construct()
    {
        $taxonomy = 'flexi_category';
        add_filter('manage_edit-' . $taxonomy . '_columns', array($this, 'new_column_category'));
        add_action('manage_' . $taxonomy . '_custom_column', array($this, 'manage_category_columns'), 10, 3);

        $taxonomy_tag = 'flexi_tag';
        add_filter('manage_edit-' . $taxonomy_tag . '_columns', array($this, 'new_column_tag'));
        add_action('manage_' . $taxonomy_tag . '_custom_column', array($this, 'manage_tag_columns'), 10, 3);
        add_action('template_redirect', array($this, 'category_rewrite_view_link'));
        add_shortcode('flexi-category', array($this, 'flexi_category'));
    }

    // List category/album at frontend
    public function flexi_category($params)
    {

        // Parent category
        if (isset($params['parent']) && $params['parent'] != '') {
            $term_slug = $params['parent'];
        } else {
            $term_slug = '';
        }

        // check category in url
        $term_slug_in_url = get_query_var('flexi_category');
        if ($term_slug_in_url != '') {
            $term_slug = get_query_var('flexi_category');
        }

        $term = get_term_by('slug', $term_slug, 'flexi_category');

        if ($term_slug != '') {
            $album_name = $term->name;
            $term_id = $term->term_id;
        } else {
            $album_name = '';
            $term_id = 0;
        }

        // Show album count
        if (isset($params['count']) && $params['count'] == 'show') {
            $count = true;
        } else {
            $count_category = flexi_get_option('category_count', 'flexi_categories_settings', 1);
            if ('1' == $count_category) {
                $count = true;
            } else {
                $count = false;
            }
        }

        // Hide hidden category
        $skip = array();
        $skip = flexi_hidden_album();

        $args = array(
            'orderby' => 'name',
            'order' => 'ASC',
            'hide_empty' => 0,
            'exclude' => $skip,
            'parent' => $term_id,
            'pad_counts' => 1,
            // 'include_children' => true,
            // 'nopaging' => true,

        );

        $terms = get_terms('flexi_category', $args);

        // Layout
        if (isset($params['layout'])) {
            $layout = trim($params['layout']);
        } else {
            $layout = 'basic';
        }

        $count_category = 0;
        $put = '';
        ob_start();

        // if (!empty($terms) && !is_wp_error($terms)) {
        if (!is_wp_error($terms)) {
            $check_file = FLEXI_PLUGIN_DIR . 'public/partials/layout/category/' . $layout . '/loop.php';
            if (file_exists($check_file)) {
                if (isset($params['column']) && $params['column'] > 0) {
                    $column = $params['column'];
                } else {
                    $column = flexi_get_option('column', 'flexi_image_layout_settings', 3);
                }

                if (isset($params['width']) && $params['width'] > 0) {
                    $width = $params['width'];
                } else {
                    $width = flexi_get_option('t_width', 'flexi_media_settings', 150);
                }

                if (isset($params['height']) && $params['height'] > 0) {
                    $height = $params['height'];
                } else {
                    $height = flexi_get_option('t_height', 'flexi_media_settings', 150);
                }

                // padding
                if (isset($params['padding'])) {
                    $padding = $params['padding'] . 'px';
                } else {
                    $padding = flexi_get_option('image_space', 'flexi_gallery_appearance_settings', 0) . 'px';
                }

                $category_page_link = flexi_get_button_url('', false, 'category_page', 'flexi_categories_settings');
                if ('#' != $category_page_link) {
                    wp_register_style('flexi_category_' . $layout . '_layout', FLEXI_PLUGIN_URL . '/public/partials/layout/category/' . $layout . '/style.css', null, FLEXI_VERSION);
                    wp_enqueue_style('flexi_category_' . $layout . '_layout');
                    require FLEXI_PLUGIN_DIR . 'public/partials/layout/category/attach_header.php';

                    foreach ($terms as $term) {
                        if ($count) {
                            // flexi_log($term); //wp_get_cat_postcount($term->term_id)
                            if ($term->count == 0) {
                                $count_result = '';
                            } else {
                                $count_result = '(' . flexi_total_cat_post_count($term->term_id, $term->count) . ')';
                            }
                        } else {
                            $count_result = '';
                        }
                        require FLEXI_PLUGIN_DIR . 'public/partials/layout/category/attach_loop.php';
                        $count_category++;
                    }

                    require FLEXI_PLUGIN_DIR . 'public/partials/layout/category/attach_footer.php';
                } else {
                    echo '<div id="flexi_no_record" class="flexi_alert-box flexi_error">' . __('Flexi category page is not assigned in settings.', 'flexi') . '</div>';
                }
            }
        }

        $put = ob_get_clean();
        wp_reset_query();
        wp_reset_postdata();

        if (flexi_execute_shortcode()) {
            return $put;
        } else {

            return '';
        }
    }

    public function new_column_category($columns)
    {

        $columns = array(
            'cb' => '<input type="checkbox" />',
            'name' => __('Name'),
            'shortcode' => __('Shortcode'),
            'slug' => __('Slug'),
            'posts' => __('Posts'),
        );

        return $columns;
    }
    public function manage_category_columns($out, $column_name, $cat_id)
    {
        $taxonomy = 'flexi_category';

        switch ($column_name) {
            case 'shortcode':
                $a = get_term_by('id', $cat_id, $taxonomy);
                echo '<code>[flexi-gallery album="' . esc_attr($a->slug) . '"]</code>';
                break;

            default:
                break;
        }
    }

    public function new_column_tag($columns)
    {

        $columns = array(
            'cb' => '<input type="checkbox" />',
            'name' => __('Name'),
            'shortcode' => __('Shortcode'),
            'slug' => __('Slug'),
            'posts' => __('Posts'),
        );

        return $columns;
    }
    public function manage_tag_columns($out, $column_name, $cat_id)
    {
        $taxonomy = 'flexi_tag';

        switch ($column_name) {
            case 'shortcode':
                $a = get_term_by('id', $cat_id, $taxonomy);
                echo '<code>[flexi-gallery tag="' . esc_attr($a->slug) . '"]</code>';
                break;

            default:
                break;
        }
    }

    // Redirect to category page with view is clicked at category & tag of admin dashboard
    public function category_rewrite_view_link()
    {

        $redirect_url = '';
        if (!is_feed()) {
            if (is_tax('flexi_category')) {

                $term = get_queried_object();
                $redirect_url = flexi_get_category_page_link($term, 'flexi_category');
            }

            if (is_tax('flexi_tag')) {

                $term = get_queried_object();
                $redirect_url = flexi_get_category_page_link($term, 'flexi_tag');
            }
        }

        // Redirect
        if (!empty($redirect_url)) {

            wp_redirect($redirect_url);
            exit();
        }
    }
}
// Execute
$category = new Flexi_Category();